@@ -18,11 +18,52 @@ isOpenCVInstalled <- function() {
 }
 
 
+#' @title Check Cmake Installation
+#'
+#' @description This functions checks that Cmake is installed on the system.
+#'
+#' @return A boolean indicating whether Cmake was or not installed on the system.
+#'
+#' @author Simon Garnier, \email{garnier@@njit.edu}
+#'
+#' @examples
+#' isCmakeInstalled()
+#'
+#' @export
+isCmakeInstalled <- function() {
+  cmake <- system("cmake --version", ignore.stdout = TRUE) == 0
+
+  if (cmake) {
+    cmake
+  } else {
+    cat("------------------ CMAKE NOT FOUND --------------------\n")
+    cat("\n")
+    cat("CMake was not found on the PATH. Please install CMake:\n")
+    cat("\n")
+    cat(" - installr::install.cmake()  (Windows; inside the R console)\n")
+    cat(" - yum install cmake          (Fedora/CentOS; inside a terminal)\n")
+    cat(" - apt install cmake          (Debian/Ubuntu; inside a terminal)\n")
+    cat(" - brew install cmake         (MacOS; inside a terminal with homebrew)\n")
+    cat("\n")
+    cat("Alternatively install CMake from: <https://cmake.org/>\n")
+    cat("\n")
+    cat("-------------------------------------------------------\n")
+    cat("\n")
+    cmake
+  }
+}
+
+
 #' @title Install OpenCV
 #'
 #' @description This function will attempt to download, compile and install
 #'  OpenCV on the system. This process will take several minutes.
 #'
+#' @param batch A boolean indicating whether to skip (\code{TRUE}) or not (\code{FALSE},
+#'  the default) the interactive installation dialog. This is useful when OpenCV needs
+#'  to be installed in a non-interactive environment (e.g., during a batch installation
+#'  on a server).
+#'
 #' @return A boolean indicating whether OpenCV was or not installed on the system.
 #'
 #' @author Simon Garnier, \email{garnier@@njit.edu}
@@ -33,7 +74,7 @@ isOpenCVInstalled <- function() {
 #' }
 #'
 #' @export
-installOpenCV <- function() {
+installOpenCV <- function(batch = FALSE) {
   install <- 0
 
   if (interactive()) {
@@ -50,9 +91,17 @@ installOpenCV <- function() {
       install <- utils::menu(c("yes", "no"), title = "OpenCV is not installed on this system. Would you like to install it now? This will take several minutes.")
     }
   } else {
-    warning("OpenCV can only be installed in interactive mode.")
+    if (batch) {
+      warning("OpenCV being installed in non-interactive mode!")
+      install <- 1
+    } else {
+      warning("OpenCV can only be installed in interactive mode or if the batch mode is activated.")
+    }
   }
 
+  if (!isCmakeInstalled())
+    install <- 0
+
   if (install == 1) {
     pkgPath <- find.package("ROpenCVLite")
     installPath <- gsub("ROpenCVLite", "", pkgPath)
@@ -66,18 +115,11 @@ installOpenCV <- function() {
       tmpDir <- base::tempdir()
       dir.create(tmpDir, showWarnings = FALSE)
 
-      utils::download.file("https://github.com/opencv/opencv/archive/4.1.0.tar.gz",
-                           paste0(tmpDir, "/opencv-4.1.0.tar.gz"))
-      utils::untar(paste0(tmpDir, "/opencv-4.1.0.tar.gz"),
+      utils::download.file("https://github.com/opencv/opencv/archive/4.1.2.tar.gz",
+                           paste0(tmpDir, "/opencv-4.1.2.tar.gz"))
+      utils::untar(paste0(tmpDir, "/opencv-4.1.2.tar.gz"),
                    exdir = tmpDir)
 
-      file.copy(paste0(pkgPath, "/OpenCVDetectDirectX.4.1.0.cmake"),
-                paste0(tmpDir, "/opencv-4.1.0/cmake/OpenCVDetectDirectX.cmake"),
-                overwrite = TRUE)
-      file.copy(paste0(pkgPath, "/OpenCVDetectOpenCL.4.1.0.cmake"),
-                paste0(tmpDir, "/opencv-4.1.0/cmake/OpenCVDetectOpenCL.cmake"),
-                overwrite = TRUE)
-
       arch <- c("64", "32")
       archAvail <- c(dir.exists(paste0(R.home(), "/bin/x64")),
                      dir.exists(paste0(R.home(), "/bin/i386")))
@@ -88,7 +130,7 @@ installOpenCV <- function() {
 
         for (i in 1:2) {
           if (archAvail[i]) {
-            sourceDir <- paste0(tmpDir, "/opencv-4.1.0/")
+            sourceDir <- paste0(tmpDir, "/opencv-4.1.2/")
             buildDir <- paste0(sourceDir, "build", arch[i])
             dir.create(buildDir, showWarnings = FALSE)
             system(paste0('cmake -G "Unix Makefiles" -DCMAKE_C_COMPILER=', rtoolsPath, '/mingw_', arch[i], '/bin/gcc.exe -DCMAKE_CXX_COMPILER=', rtoolsPath, '/mingw_', arch[i], '/bin/g++.exe -DCMAKE_RC_COMPILER=', rtoolsPath, '/mingw_', arch[i], '/bin/windres.exe -DCMAKE_MAKE_PROGRAM=', rtoolsPath, '/mingw_', arch[i], '/bin/mingw32-make.exe -DENABLE_PRECOMPILED_HEADERS=OFF -DENABLE_CXX11=ON -DBUILD_ZLIB=ON -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DBUILD_matlab=OFF -DBUILD_opencv_java=OFF -DBUILD_opencv_python2=OFF -DBUILD_opencv_python3=OFF -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DWITH_MSMF=OFF -DBUILD_PROTOBUF=OFF -DBUILD_SHARED_LIBS=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=', openCVPath, ' -B', buildDir, ' -H', sourceDir))
@@ -104,16 +146,16 @@ installOpenCV <- function() {
       tmpDir <- base::tempdir()
       dir.create(tmpDir, showWarnings = FALSE)
 
-      utils::download.file("https://github.com/opencv/opencv/archive/4.1.0.zip",
-                           paste0(tmpDir, "/opencv-4.1.0.zip"))
-      utils::unzip(paste0(tmpDir, "/opencv-4.1.0.zip"),
+      utils::download.file("https://github.com/opencv/opencv/archive/4.1.2.zip",
+                           paste0(tmpDir, "/opencv-4.1.2.zip"))
+      utils::unzip(paste0(tmpDir, "/opencv-4.1.2.zip"),
                    exdir = tmpDir)
 
-      file.copy(paste0(pkgPath, "/OpenCVModule.4.1.0.cmake"),
-                paste0(tmpDir, "/opencv-4.1.0/cmake/OpenCVModule.cmake"),
+      file.copy(paste0(pkgPath, "/OpenCVModule.4.1.2.cmake"),
+                paste0(tmpDir, "/opencv-4.1.2/cmake/OpenCVModule.cmake"),
                 overwrite = TRUE)
 
-      sourceDir <- paste0(tmpDir, "/opencv-4.1.0/")
+      sourceDir <- paste0(tmpDir, "/opencv-4.1.2/")
       buildDir <- paste0(sourceDir, "build")
       dir.create(buildDir, showWarnings = FALSE)
       system(paste0("cmake -DWITH_IPP=ON -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DBUILD_opencv_matlab=OFF -DBUILD_opencv_java=OFF -DBUILD_opencv_python2=OFF -DBUILD_opencv_python3=OFF -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DINSTALL_CREATE_DISTRIB=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=", openCVPath, " -B", buildDir, ' -H', sourceDir))
@@ -121,7 +163,7 @@ installOpenCV <- function() {
       system(paste0("make -C ", buildDir, " all install"))
     }
   } else {
-    message("OpenCV was not installed at this time. You can install it at any time by using the installOpenCV() function in interactive mode.")
+    message("OpenCV was not installed at this time. You can install it at any time by using the installOpenCV() function.")
   }
 
   isOpenCVInstalled()
